#[non_exhaustive]pub enum GridError {
TooLarge {
rows: u64,
cols: u64,
},
Overlap {
at: GridCoord,
},
OverhangsBottom {
at: GridCoord,
},
NotTiled {
at: GridCoord,
},
}Expand description
Why a table’s cells do not tile a well-formed logical grid.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TooLarge
The grid would exceed MAX_GRID_POSITIONS.
Fields
Overlap
A cell’s span covers a position already covered by another cell.
OverhangsBottom
A cell’s row_span extends past the table’s last row.
NotTiled
A position inside the grid rectangle is covered by no cell.