ValidationError

Enum ValidationError 

#[non_exhaustive]
pub enum ValidationError {
Show 19 variants EmptyDocument, EmptySection { section_index: usize, }, EmptyParagraph { section_index: usize, paragraph_index: usize, }, EmptyTable { section_index: usize, paragraph_index: usize, run_index: usize, }, EmptyTableRow { section_index: usize, paragraph_index: usize, run_index: usize, row_index: usize, }, InvalidSpan { field: &'static str, value: u16, section_index: usize, paragraph_index: usize, run_index: usize, row_index: usize, cell_index: usize, }, EmptyTextBox { section_index: usize, paragraph_index: usize, run_index: usize, }, InvalidGroupChild { section_index: usize, paragraph_index: usize, run_index: usize, }, EmptyFootnote { section_index: usize, paragraph_index: usize, run_index: usize, }, EmptyEndnote { section_index: usize, paragraph_index: usize, run_index: usize, }, InvalidPolygon { section_index: usize, paragraph_index: usize, run_index: usize, vertex_count: usize, }, InvalidShapeDimension { section_index: usize, paragraph_index: usize, run_index: usize, shape_type: &'static str, }, EmptyChartData { section_index: usize, paragraph_index: usize, run_index: usize, }, EmptyEquation { section_index: usize, paragraph_index: usize, run_index: usize, }, EmptyCategoryLabels { section_index: usize, paragraph_index: usize, run_index: usize, }, MismatchedSeriesLengths { section_index: usize, paragraph_index: usize, run_index: usize, series_name: String, x_len: usize, y_len: usize, }, EmptyTableCell { section_index: usize, paragraph_index: usize, run_index: usize, row_index: usize, cell_index: usize, }, NonLeadingTableHeaderRow { section_index: usize, paragraph_index: usize, run_index: usize, row_index: usize, }, InvalidSummaryToken { section_index: usize, paragraph_index: usize, run_index: usize, token: String, },
}
Specific validation failures with precise location context.

Every variant carries enough information to pinpoint the exact location of the problem (section index, paragraph index, etc.).

Marked #[non_exhaustive] so future phases can add variants without a breaking change.

Examples

use hwpforge_core::error::ValidationError;

let err = ValidationError::EmptySection { section_index: 2 };
assert!(err.to_string().contains("Section 2"));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyDocument

The document contains zero sections.



EmptySection

A section contains zero paragraphs.

Fields

section_index: usize

Zero-based index of the offending section.



EmptyParagraph

A paragraph contains zero runs.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index within the section.



EmptyTable

A table contains zero rows.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



EmptyTableRow

A table row contains zero cells.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

row_index: usize

Zero-based row index within the table.



InvalidSpan

A span value (col_span or row_span) is zero.

Fields

field: &'static str

Which span field failed (“col_span” or “row_span”).

value: u16

The invalid value.

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

row_index: usize

Zero-based row index.

cell_index: usize

Zero-based cell index.



EmptyTextBox

A TextBox control contains zero paragraphs.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



InvalidGroupChild

A Group control contains a child that is not a drawing shape.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



EmptyFootnote

A Footnote control contains zero paragraphs.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



EmptyEndnote

An Endnote control contains zero paragraphs.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



InvalidPolygon

A Polygon control has fewer than 3 vertices.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

vertex_count: usize

Number of vertices found.



InvalidShapeDimension

A shape (Ellipse or Polygon) has zero width or height.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

shape_type: &'static str

Type of shape (“Ellipse” or “Polygon”).



EmptyChartData

A Chart control has no data series.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



EmptyEquation

An Equation control has an empty script.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



EmptyCategoryLabels

A Category chart has an empty categories list.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.



MismatchedSeriesLengths

An XY series has mismatched x/y value lengths.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

series_name: String

Name of the offending series.

x_len: usize

Length of x_values.

y_len: usize

Length of y_values.



EmptyTableCell

A table cell contains zero paragraphs.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

row_index: usize

Zero-based row index.

cell_index: usize

Zero-based cell index.



NonLeadingTableHeaderRow

A header row appears after a non-header row.

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

row_index: usize

Zero-based row index.



InvalidSummaryToken

A SUMMERY token (UnknownSummary.token) is empty or does not start with $. HWPX SUMMERY Command strings always have the $word shape (Wave 12n).

Fields

section_index: usize

Zero-based section index.

paragraph_index: usize

Zero-based paragraph index.

run_index: usize

Zero-based run index.

token: String

The offending token.

Implementations

Source

impl ValidationError

pub fn code(&self) -> CoreErrorCode

Returns the numeric error code for this validation error.