#[non_exhaustive]pub enum RunContent {
Text(String),
Table(Box<Table>),
Image(Image),
Control(Box<Control>),
}Expand description
The content of a run.
Marked #[non_exhaustive] so future content types can be added
without a breaking change.
Design Decision
Table and Control are boxed to keep the enum size small.
The common case (Text) is 24 bytes (a String). Without boxing,
the enum would be ~88 bytes (dominated by the Control variant).
Examples
use hwpforge_core::run::RunContent;
let text = RunContent::Text("Hello".to_string());
assert!(text.is_text());
assert_eq!(text.as_text(), Some("Hello"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Text(String)
Plain text.
Table(Box<Table>)
An inline table (boxed for enum size optimization).
Image(Image)
An inline image.
Control(Box<Control>)
A control element (boxed for enum size optimization).
Implementations
Sourceimpl RunContent
impl RunContent
Sourcepub fn as_text(&self) -> Option<&str>
pub fn as_text(&self) -> Option<&str>
Returns the text content if this is a Text variant.
Examples
use hwpforge_core::run::RunContent;
let content = RunContent::Text("hello".to_string());
assert_eq!(content.as_text(), Some("hello"));
let content = RunContent::Text(String::new());
assert_eq!(content.as_text(), Some(""));Sourcepub fn as_control(&self) -> Option<&Control>
pub fn as_control(&self) -> Option<&Control>
Returns the control if this is a Control variant.
Sourcepub fn is_control(&self) -> bool
pub fn is_control(&self) -> bool
Returns true if this is a Control variant.