#[non_exhaustive]pub struct TableRow {
pub cells: Vec<TableCell>,
pub height: Option<HwpUnit>,
pub is_header: bool,
}Expand description
A single row of a table.
Examples
use hwpforge_core::table::{TableRow, TableCell};
use hwpforge_core::paragraph::Paragraph;
use hwpforge_foundation::{HwpUnit, ParaShapeIndex};
let row = TableRow::new(vec![
TableCell::new(vec![Paragraph::new(ParaShapeIndex::new(0))], HwpUnit::from_mm(50.0).unwrap()),
TableCell::new(vec![Paragraph::new(ParaShapeIndex::new(0))], HwpUnit::from_mm(50.0).unwrap()),
]);
assert_eq!(row.cells.len(), 2);Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cells: Vec<TableCell>Cells in this row.
height: Option<HwpUnit>Optional fixed row height. None means auto-height.
is_header: boolWhether this row is part of the table’s leading header-row block.
Implementations
Sourceimpl TableRow
impl TableRow
Sourcepub fn new(cells: Vec<TableCell>) -> Self
pub fn new(cells: Vec<TableCell>) -> Self
Creates a new table row with the given cells and auto-calculated height.
Examples
use hwpforge_core::table::{TableRow, TableCell};
use hwpforge_core::paragraph::Paragraph;
use hwpforge_foundation::{HwpUnit, ParaShapeIndex};
let cell = TableCell::new(
vec![Paragraph::new(ParaShapeIndex::new(0))],
HwpUnit::from_mm(40.0).unwrap(),
);
let row = TableRow::new(vec![cell]);
assert!(row.height.is_none());Sourcepub fn with_height(cells: Vec<TableCell>, height: HwpUnit) -> Self
pub fn with_height(cells: Vec<TableCell>, height: HwpUnit) -> Self
Creates a new table row with an explicit fixed height.
Examples
use hwpforge_core::table::{TableRow, TableCell};
use hwpforge_core::paragraph::Paragraph;
use hwpforge_foundation::{HwpUnit, ParaShapeIndex};
let cell = TableCell::new(
vec![Paragraph::new(ParaShapeIndex::new(0))],
HwpUnit::from_mm(40.0).unwrap(),
);
let row = TableRow::with_height(vec![cell], HwpUnit::from_mm(20.0).unwrap());
assert!(row.height.is_some());Sourcepub fn with_header(self, is_header: bool) -> Self
pub fn with_header(self, is_header: bool) -> Self
Marks whether this row belongs to the table’s leading header-row block.